from django.apps import AppConfig


class DjangoSecurePasswordInput(AppConfig):
    name = 'django_secure_password_input'
